@@ -5,15 +5,15 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-events", "1.60.0", __name__[0:-6], "aws-events@1.60.0.jsii.tgz"
+    "@aws-cdk/aws-events", "1.65.0", __name__[0:-6], "aws-events@1.65.0.jsii.tgz"
 )
 
 __all__ = [
